wiswa
=====

.. include:: badges.rst

Commands
--------

.. click:: wiswa.main:main
  :prog: wiswa
  :nested: full

.. only:: html

   Library
   -------
   .. automodule:: wiswa
      :members:

   .. automodule:: wiswa.constants
      :members:

   .. automodule:: wiswa.extensions
      :members:

   .. automodule:: wiswa.typing
      :members:

   .. automodule:: wiswa.utils
      :members:

   Indices and tables
   ==================

   * :ref:`genindex`
   * :ref:`modindex`
